# sage_setup: distribution = sagemath-environment
# Sage version information for Python scripts
# This file is auto-generated by the update-version script, do not edit!
version = '10.6.31.rc3'
date = '2025-10-22'
banner = 'passagemath version 10.6.31.rc3, Release Date: 2025-10-22'
